/*
 * XMLElement.java
 *
 * Created on February 18, 2002, 8:27 AM
 */
import java.util.*;
/**
 * This class is used to represent an XML Element
 *
 * @author  andrewm
 * @version 
 */
public class XMLElement 
{
	// Path id of the element
	private int pathID;
	
	// Name of the element
	private String name;
	
	// Starting index of the element
	private int startIndex;
	
	// Ending index of the element
	private int endIndex;
	
	// Element id of the previous element
	private int previousElementID;
	
	/** 
	 * Creates new XMLElement 
	 *
	 * @param pathID Value of the path id
	 * @param name Value of the elements name
	 * @param startIndex Value of the elements starting index
	 * @param previousElementID Element ID of the previous element
	 */
    public XMLElement( int pathID, String name, int startIndex, int previousElementID ) 
	{
		this.pathID = pathID;
		this.name = name;
		this.startIndex = startIndex;
		this.previousElementID = previousElementID;
    }

	/**
	 * Returns the ending index
	 *
	 * @return int Value representing the ending index
	 */
	public int getEndIndex()
	{
		return endIndex;
	}
	
	/**
	 * Returns the name of the element
	 *
	 * @return String Name of the element
	 */
	public String getName()
	{
		return name;
	}
	
	/**
	 * Returns the path id of the element
	 *
	 * @return int Path id of the element
	 */
	public int getPathID()
	{
		return pathID;
	}
	
	/** 
	 * Returns the element id of the previous element
	 *
	 * @return int Previous elements id
	 */
	public int getPreviousElementID()
	{
		return previousElementID;
	}
	
	/**
	 * Returns the starting index
	 *
	 * @return int Starting index
	 */
	public int getStartIndex()
	{
		return startIndex;
	}
	
	/**
	 * Sets the ending index to the int passed in
	 *
	 * @param endIndex New value of the ending index
	 */
	public void setEndIndex( int endIndex )
	{
		this.endIndex = endIndex;
	}
	
	/**
	 * Sets the name of the element to the String passed in
	 *
	 * @param name New value for the name of the element
	 */
	public void setName( String name )
	{
		this.name = name;
	}
	
	/**
	 * Sets the path id of the element to the in passed in
	 *
	 * @param pathID New value for the path id
	 */
	public void setPathID( int pathID )
	{
		this.pathID = pathID;
	}
	
	/**
	 * Sets the previous elements id to the int passed in
	 *
	 * @param elementID New value for the element id of the previous element
	 */
	public void setPreviousElementID( int elementID )
	{ 
		this.previousElementID = elementID;
	}
	
	/**
	 * Sets the starting index to the int passed in
	 *
	 * @param startIndex New value for the starting index
	 */
	public void setStartIndex( int startIndex )
	{
		this.startIndex = startIndex;
	}
}
